from setuptools import setup

setup(name='dav_probdist',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['dav_probdist'],
      author = 'David Hazarika',
      zip_safe=False)
